==> qore-1.9.0.tar.bz2: qore-1.9.0/docs/modules/WebSocketUtil/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore WebSocketUtil Module Reference", "index.html", [
    [ "WebSocketUtil Module", "index.html", [
      [ "Introduction to the WebSocketUtil Module", "index.html#websocketutilintro", null ],
      [ "WebSocketUtil Module Release History", "index.html#websocketutil_relnotes", [
        [ "v1.4.1", "index.html#wsu_v141", null ],
        [ "v1.4", "index.html#wsu_v14", null ],
        [ "v1.3", "index.html#wsu_v13", null ],
        [ "v1.2", "index.html#wsu_v12", null ],
        [ "v1.1", "index.html#wsu_v11", null ],
        [ "v1.0", "index.html#wsu_v10", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__debug__rs__options.html#ga081d0b135c04fc78bee0926759f49c30",
"group__functional__domain__constants.html#gaed32c700f988d21a2a3c55ccf36f451c",
"group__misc__functions.html#ga8a7ea9de612741d9bb26bf926d211c71",
"group__signal__constants.html#ga3d2b5c4187540623d6ea22c5225bdd3a",
"group__tattr__output__mode__constants.html#ga00759299e93bb514684789a1977f71f4"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.12.2.tar.bz2: qore-1.12.2/docs/modules/WebSocketUtil/html/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore WebSocketUtil Module Reference", "index.html", [
    [ "WebSocketUtil Module", "index.html", [
      [ "Introduction to the WebSocketUtil Module", "index.html#websocketutilintro", null ],
      [ "WebSocketUtil Module Release History", "index.html#websocketutil_relnotes", [
        [ "v1.4.1", "index.html#wsu_v141", null ],
        [ "v1.4", "index.html#wsu_v14", null ],
        [ "v1.3", "index.html#wsu_v13", null ],
        [ "v1.2", "index.html#wsu_v12", null ],
        [ "v1.1", "index.html#wsu_v11", null ],
        [ "v1.0", "index.html#wsu_v10", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__debug__rs__options.html#ga081d0b135c04fc78bee0926759f49c30",
"group__functional__domain__constants.html#gaed32c700f988d21a2a3c55ccf36f451c",
"group__misc__functions.html#ga8851e308445e0388408b8b2cca344088",
"group__signal__constants.html#ga351bab31a52656719e7f81301449e3e6",
"group__tattr__output__mode__constants.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
